@@ -563,8 +563,11 @@ sub _end {
     # Found
     ++$found and last if $next->[1] eq $end;
 
-    # HTML inline tags stop here
-    return if !$self->xml && $HTML_BLOCK{$next->[1]} && !$HTML_BLOCK{$end};
+    # Don't cross block tags that are not optional tags
+    return
+      if !$self->xml
+        && $HTML_BLOCK{$next->[1]}
+        && !$HTML_OPTIONAL{$next->[1]};
 
     $next = $next->[3];
   }
@@ -597,12 +600,13 @@ sub _end {
 sub _match_element {
   my ($self, $candidate, $selectors) = @_;
 
-  # Match
-  my @selectors = reverse @$selectors;
-  my $first     = 2;
-  my ($current, $marker, $snapback);
+  my @selectors  = reverse @$selectors;
+  my $first      = 2;
   my $parentonly = 0;
-  my $siblings;
+  my $tree       = $self->tree;
+  my ($current, $marker, $snapback, $siblings);
+
+  # Match
   for (my $i = 0; $i <= $#selectors; $i++) {
     my $selector = $selectors[$i];
 
@@ -666,6 +670,9 @@ sub _match_element {
       else {
         return
           unless $current = $current ? $current->[3] : $candidate;
+
+        # Don't search beyond the current tree
+        return if $current eq $tree;
       }
 
       # Not a tag
