@@ -51,7 +51,7 @@ sub detect {
 
       # Turn into absolute path
       $self->{_parts} =
-        [File::Spec->splitdir(abs_path(File::Spec->catdir(@home)))];
+        [File::Spec->splitdir(abs_path(File::Spec->catdir(@home) || '.'))];
     }
   }
 
@@ -76,13 +76,8 @@ sub lib_dir {
 sub list_files {
   my ($self, $dir) = @_;
 
-  # Parts
   my $parts = $self->{_parts} || [];
-
-  # Root
   my $root = File::Spec->catdir(@$parts);
-
-  # Directory
   $dir = File::Spec->catdir($root, split '/', ($dir || ''));
 
   # Read directory
